
package extractTerms;

import java.util.*;
import java.io.*;
import extractTerms.*;

/**
 * Example for the method extract of ExtractTerms class.
 *
 * @author Thomas Heitz for LRI Paris XI University
 * @version 0.2 09/07/2003
 * @since 27/03/2003
 * @see ExtractTerms
 */
public class ExtractTermsExample {

    /**
     * Just extract possible terms of the input file and write results in
     * the output file.
     *
     * The default parameters works with Penn Treebank tags and extract
     * adjective-noun and noun-adjective-noun possible terms.
     *
     * @param args arguments of program
     * <br>1 - name of input file containing text to analyse
     * <br>2 - name of output file containing results
     *
     * <p>The default hard-coded other parameters are :
     *
     * <pre>
     * regexUnit = "([^/]+/\\S+) "
     * regexSentPhraSeparator = "([^/]+/[.,?!;:()\"])"
     * regexNameOfText = "---/(.*)"
     * regex2Units1 = "[^/]+/JJ[RS]? "
     * regex2Units2 = "[^/]+/NN[PS]?[S] "
     * tagKept2Units = 2
     * regex3Units1 = "[^/]+/NN[PS]?[S] "
     * regex3Units2 = "[^/]+/IN "
     * regex3Units3 = "[^/]+/NN[PS]?[S] "
     * tagKept3Units = 3
     * formula = 1
     * tfidf = false
     * pruning2Units = 4
     * pruning3Units = 4
     * maxResults2Units = 500
     * maxResults3Units = 500
     * separator = "/"
     * relation2Units = 0
     * relation3Units = 0
     * occFirst = false
     * </pre>
     * @see ExtractTerms#ExtractTerms(java.lang.String, java.lang.String,
     * java.lang.String, java.lang.String, java.lang.String,
     * java.lang.String, int, java.lang.String, java.lang.String,
     * java.lang.String, int, int, boolean, int, int, int, int,
     * java.lang.String, int, int, boolean)
     * ExtractTerms constructor for more information on default parameters.
     */
    static public void main(String args[]) {

        ExtractTerms et;
        String inputFile, outputFile;
        String regexUnit, regexSentPhraSeparator;
        String regexNameOfText;
        String regex2Units1, regex2Units2;
        int tagKept2Units;
        String regex3Units1, regex3Units2, regex3Units3;
        int tagKept3Units;
        int formula;
        boolean tfidf;
        int pruning2Units, pruning3Units;
        int maxResults2Units, maxResults3Units;
        String separator;
        int relation2Units;
        int relation3Units;
        boolean occFirst;
        int iteration;

        String result;
        Iterator it, it2;

        // test command line parameters
        if (args.length < 2) {
            System.out.println("Error : You should provide an input "
                             +"file name as a first argument and an output "
                             +"file name as a second argument.\n");
            System.exit(0);
        }
        inputFile = args[0];
        outputFile = args[1];

        // objects initialisation
        regexUnit = "([^/]+/\\S+) ";
        regexSentPhraSeparator = "([^/]+/[.,?!;:()\"])";
        regexNameOfText = "---/(.*)";
        regex2Units1 = "[^/]+/JJ[RS]? ";
        regex2Units2 = "[^/]+/NN[PS]?[S] ";
        tagKept2Units = 2;
        regex3Units1 = "[^/]+/NN[PS]?[S] ";
        regex3Units2 = "[^/]+/IN ";
        regex3Units3 = "[^/]+/NN[PS]?[S] ";
        tagKept3Units = 3;
        tfidf = false;
        pruning2Units = 4;
        pruning3Units = 4;
        maxResults2Units = 500;
        maxResults3Units = 500;
        separator = "/";
        relation2Units = 0;
        relation3Units = 0;
        occFirst = false;
        formula = 1;

        iteration = 1;

        et = new ExtractTerms(inputFile,
                              regexUnit,
                              regexNameOfText,
                              regexSentPhraSeparator,
                              regex2Units1,regex2Units2,
                              tagKept2Units,
                              regex3Units1, regex3Units2, regex3Units3,
                              tagKept3Units,
                              formula,
                              tfidf,
                              pruning2Units, pruning3Units,
                              maxResults2Units,
                              maxResults3Units,
                              separator,
                              relation2Units,
                              relation3Units,
                              occFirst);

       

        if (!et.extract(new TreeSet(), iteration, null)) {
            System.out.println("Error in extraction.");
            System.exit(0);
        }

        System.out.println("Writing results in ["+outputFile+"]...");

        // write the results in the output file
         try {
            PrintWriter out =
                new PrintWriter(new BufferedWriter(
                                       new FileWriter(outputFile)));

            out.println("Unique units = "+et.getTotalUnitsWithoutDouble());
            out.println(); out.println();

            out.println("Relevancy results for units pair");
            out.println("Units pair/unique/redondancy = "
                        +et.getTotalUnitsPair()+"/"
                        +et.getTotalUnitsPairWithoutDouble()+"/"
                        +(et.getTotalUnitsPair()
                          -et.getTotalUnitsPairWithoutDouble())*100
                        /et.getTotalUnitsPair()+"%");
            out.println("Units pair after pruning/pourcent/threshold = "
                        +et.getResults2Units().size()+"/"
                        +(et.getTotalUnitsPairWithoutDouble()
                          -et.getResults2Units().size())*100
                        /et.getTotalUnitsPairWithoutDouble()
                        +"%/"+pruning2Units);
            out.println();
            out.println("measure unit1 unit2 (nb of occurrence, "
                        +"nb of text where present)");
            it = et.getResults2Units().iterator();
            while (it.hasNext()) { out.println(it.next()); }
            out.println();

            out.println("Relevancy results for units triple");
            out.println("Units triple/unique/redondancy = "
                        +et.getTotalUnitsTriple()+"/"
                        +et.getTotalUnitsTripleWithoutDouble()+"/"
                        +(et.getTotalUnitsTriple()
                          -et.getTotalUnitsTripleWithoutDouble())*100
                        /et.getTotalUnitsTriple()+"%");
            out.println("Units triple after pruning/pourcent/threshold = "
                        +et.getResults3Units().size()+"/"
                        +(et.getTotalUnitsTripleWithoutDouble()
                          -et.getResults3Units().size())*100
                        /et.getTotalUnitsTripleWithoutDouble()
                        +"%/"+pruning3Units);
            out.println();
            out.println("measure unit1 unit2 unit 3 (nb of occurrence, "
                        +"nb of text where present)");
            it = et.getResults3Units().iterator();
            while (it.hasNext()) { out.println(it.next()); }
            out.println();

            out.close();

        } catch (IOException ioe) {
            System.out.println(ioe.getMessage());
            System.exit(0);
       }
    } // method main

} // class ExtractTermsExample
